
// Airfares.java
// Andrew Davison, June 2005 (ad@fivedots.coe.psu.ac.th)

/* Extract information from airfares.txt, which has the format:

    Roundtrip Fares Departing From <from>, <State> To
    ---------------------------------------------
    \t $<price> \t  <to>, <state> \n
    \t $<price> \t  <to>, <state> \n
     :
    \t $<price> \t  <to>, <state> \n
    \n

  then repeat.

  Extraction methods:
  ------------------
  showTripPrice() reports the price (if any) of a flight for from-->to

  There is also a showTrips() method for printing out all the trip
  regions.
*/

import java.io.*;


public class Airfares 
{

  public Airfares()
  {
    Region topR = new Region("airfares.txt");

    // showTrips(topR);
    showTripPrice(topR, "PHILADELPHIA", "PITTSBURGH");
    showTripPrice(topR, "BOSTON", "PITTSBURGH");
    showTripPrice(topR, "PHILADELPHIA", "WILMSLOW");
    showTripPrice(topR, "WILMSLOW", "PHILADELPHIA");
  } // end of Airfares()


  private void showTrips(Region topR)
  // print each round trip region
  {
    RegionIterator tripRegions = new RegionIterator(topR, "Roundtrip", "\n\n");
    int i=1;
    while (tripRegions.hasNext()) {
      Region r = (Region) tripRegions.next();
      System.out.println("Region match " + i + ": \"" + r + "\"");
      i++;
    }
  }  // end of showTrips()
 

  private void showTripPrice(Region topR, String from, String to)
  // show the price (if any) of a flight for from-->to
  {
    RegionIterator tripRegions = new RegionIterator(topR, "Roundtrip", "\n\n");
                  // extract each trip region, and iterate through them
    while (tripRegions.hasNext()) {
      Region tripRegion = (Region) tripRegions.next();
      Region fromRegion = tripRegion.match("From ", ", ");
      if (fromRegion.contains(from)) {   // this trip is about <from>
        showToPrice(tripRegion, from, to);
        return;
      }
    }
    System.out.println("No fares found from " + from);
  }  // end of showTripPrice()


  private void showToPrice(Region tripRegion, String from, String to)
  /* Iterate through the to lines for this trip region, and print 
     the airfare going to <to>, if one is found. 
  */
  {
    RegionIterator toRegions = 
              new RegionIterator(tripRegion, "$", ", ");   // the <to> lines
    while (toRegions.hasNext()) {
      Region toRegion = (Region) toRegions.next();
      // System.out.println("To Region match : \"" + toRegion + "\"");
      String[] toInfo = toRegion.toString().split("\t+");   
                // the info has the format  "price \t to"

      // for (int i=0; i < toInfo.length; i++)
      //   System.out.println(toInfo[i]);

      if (toInfo[1].equals(to)) {    // found <to>
        System.out.println(from + " --> " + to + ": $" + toInfo[0]);  // show fare
        return;
      }
    }
    System.out.println("No " + from + " --> " + to + " price info");
  }  // end of showToPrice()

  // -------------------- main() ---------------------

  public static void main(String args[])
  {  new Airfares();  } 

 } // end of Airfares class
