
// AtomicNum.java
// Andrew Davison, June 2005 (ad@fivedots.coe.psu.ac.th)

/* Collect the atomic names and numbers for all the atoms, and print
   them in increasing numerical order.

   The XML file, allelements.xml comes from
   http://www.ibiblio.org/xml/examples/periodic_table/
*/


public class AtomicNum 
{
  private static final int MAX_NUMBER = 130;
     /* This is used as the size of the array for atom names, and should be
        bigger than the largest possible atomic number (which is 112). */

  private static final int NUM_COLS = 4;  // used for pretty printing

  private String atoms[];   
      /* store for atom names, placed according to their atomic numbers used
         as indicies. */
  private int maxAtomNumber;


  public AtomicNum()
  {
    // initilize the atom names store
    atoms = new String[MAX_NUMBER];
    for(int i=0; i < MAX_NUMBER; i++)
     atoms[i] = null;
    maxAtomNumber = 0;

    Region topR = new Region("allElements.xml");
    RegionIterator rit1 = new RegionIterator(topR, "ATOM");
        // iterator through all the atoms   
    storeAtoms(rit1);
    showAtoms();
  } // end of AtomicNum()
 

  private void storeAtoms(RegionIterator rit)
  // extract the name and atomic number for each atom 
  {
    Region r, nameRegion, numRegion;
    int atomicNum;
    while (rit.hasNext()) {
      r = (Region) rit.next();
      // System.out.println(r);
      nameRegion = r.tagMatch("NAME");
      numRegion = r.tagMatch("ATOMIC_NUMBER");
      atomicNum = 0;  // default
      try {
        atomicNum = Integer.parseInt( numRegion.toString() );
      }
      catch (NumberFormatException ex) {}
      // System.out.println(nameRegion + " Atomic No.: " + atomicNum);
      
      if (atomicNum != 0) {
        atoms[atomicNum] = nameRegion.toString();  
           // store the atom name at the atom number position in atoms[]
        if (atomicNum > maxAtomNumber)    // remember the largest number
          maxAtomNumber = atomicNum;
      }
    }
  } // end of storeAtoms()


  private void showAtoms()
  /* Display the (atom number, atom name) pairs, from 1--maxAtomNumber */
  {
    // System.out.println("Max Atomic No.: " + maxAtomNumber);
    int colNum = 0;
    for(int i=1; i <= maxAtomNumber; i++) {   // atom numbers start at 1
      if (atoms[i] == null)
        System.out.print("(" + i + ", -----)  ");   // no atom name (should not happen)
      else
        System.out.print("(" + i + ", " + atoms[i] + ")  ");
      colNum++;
      if (colNum == NUM_COLS) {
        System.out.println();
        colNum = 0;
      }
    }
    System.out.println();
  }  // end of showAtoms()



  // -------------------- main() ---------------------

  public static void main(String args[])
  { new AtomicNum();  } 

 } // end of AtomicNum class
