
// CheckAmazon.java
// Andrew Davison, June 2005 (ad@fivedots.coe.psu.ac.th)

/* For each ISBN in the isbns[] array, visit Amazon and show the book's:
        title, list price, Amazon price, 
        star rating, number of reviews,
        sales rank

   This shows the use of the Region class (and others) for doing
   search of poorly/semi-structured data on Web pages.
*/

import java.io.*;


public class CheckAmazon 
{
  /* The fixed part of the book's URL at Amazon; add the book's
     ISBN to complete the URL. */
  private static final String AMAZON_URL = 
                   "http://www.amazon.com/exec/obidos/tg/detail/-/";

  private String[] isbns = {"0596007302", "1592730051", "1584503262", "1590591232"};
     // ISBNs of some Java gaming books; change this to suit your interests

  public CheckAmazon()
  {
    for (int i=0; i< isbns.length; i++) {
      System.out.println("Retrieving Amazon's page for " + isbns[i]);
      Region topR = new Region(AMAZON_URL + isbns[i]);
      showPageInfo(topR);
      System.out.println();
    }
  } // end of CheckAmazon()
 

  private void showPageInfo(Region r)
  {
    System.out.println("Title: " + r.tagMatch("title")); 
       // The title is between the tags <title> ... </title>

    showPrices(r);       // list and sale prices
    showReviewInfo(r);   // star rating, and no. of reviews
    showRank(r);         // Amazon's sales rank for the book
  }  // end of showPageInfo()



  private void showPrices(Region r)
  /* The list price and Amazon prices are embedded in text of the
     type:
        <tr>
          <td class="productLabel">List Price:</td>
          <td class="listprice">$44.95</td>
        </tr>

        <tr>
          <td class="productLabel">Price:</td>
          <td><b class="price">$29.67</b>
  */
  {
    Region pricesRegion = r.match("List Price:", "/b>");

    // the code should really check if pricesRegion == null at this point
    Region listPriceRegion = pricesRegion.match(">$", "</td");
    Region amazonPriceRegion = pricesRegion.match(2, ">$", 1, "<");

    System.out.println("List Price: $" + listPriceRegion +
                       "; Amazon Price: $" + amazonPriceRegion);
  }  // end of showPrices()


  private void showReviewInfo(Region r)
  /* The number of stars and number of reviews are embedded in text
     of the form:
            <img src="http://.../common/customer-reviews/stars-4-5.gif" 
            height="12" border="0" width="64" /> based on 3 reviews.
  */
  {
    Region reviewsRegion = r.match("common/customer-reviews/", "review");

    // should check if reviewsRegion == null
    Region starsRegion = reviewsRegion.match("stars-", ".gif");
    Region numReviewsRegion = reviewsRegion.match("based on ", " ");

    System.out.println("Star Rating: " + starsRegion +
                       "; No. of Reviews: " + numReviewsRegion);
  }  // end of showReviewInfo()
    


  private void showRank(Region r)
  /* The sales rank is embedded in text of the form:

         <b>Amazon.com Sales Rank:</b>
            <a href=/.../102-4291750-5206500>#8,638 in 
         Books</a>
  */
  {
    Region salesRegion = r.match("Sales Rank", "Books");

    // should check if salesRegion == null
    Region rankRegion = salesRegion.match("#", " ");
    System.out.println("Sales Rank: " + rankRegion); 
  }  // end of showRank()


  // -------------------- main() ---------------------

  public static void main(String args[])
  {  new CheckAmazon();  }

 } // end of CheckAmazon class
