
// MacbethTests.java
// Andrew Davison, June 2005 (ad@fivedots.coe.psu.ac.th)

/* Extract information from the XML file macbeth.xml, which
   I obtained from http://www.ibiblio.org/xml/examples/shakespeare/

   countWitchSpeeches() counts the number of speeches by the three
   witches.

   locateWords() counts the number of times that Macbeth mentions
   Birnam and Dunsinane.
*/

import java.io.*;


public class MacbethTests 
{

  public MacbethTests()
  {
    Region topR = new Region("macbeth.xml");
    countWitchSpeeches(topR);
    System.out.println("");
    locateWords(topR);
  } // end of MacbethTests()
 

  private void countWitchSpeeches(Region tr)
  // how many speeches do the three witches make?
  {
    int numFirst = 0;
    int numSecond = 0;
    int numThird = 0;

    RegionIterator rit = new RegionIterator(tr, "SPEAKER");
         // iterate throuh the speeches
    Region r;
    while (rit.hasNext()) {
      r = (Region) rit.next();
      // count the number of speeches by the different witches
      if (r.contains("First Witch"))
        numFirst++;
      else if (r.contains("Second Witch"))
        numSecond++;
      else if (r.contains("Third Witch"))
        numThird++;
    }
    System.out.println("First Witch speaks " + numFirst + " times");
    System.out.println("Second Witch speaks " + numSecond + " times");
    System.out.println("Third Witch speaks " + numThird + " times");
  } // end of countWitchSpeeches()


  private void locateWords(Region tr)
  /* How many times does Macbeth mention Birnam and Dunsinane?
     The answer is 10 for the entire play. */
  {
    Region speechRegion, speakerRegion;
    String speechStr;
    int numWords = 0;

    RegionIterator speechIter = new RegionIterator(tr, "SPEECH");
       // iterate throuh the speeches
    while (speechIter.hasNext()) {
      speechRegion = (Region) speechIter.next();
      // System.out.println("Speech: " + speechRegion);
      speakerRegion = speechRegion.tagMatch("SPEAKER");
      if (speakerRegion.contains("MACBETH")) {  // is the speaker Macbeth?
        speechStr = speechRegion.toString();
        numWords += countString(speechStr, "Birnam") +
                    countString(speechStr, "Dunsinane");
      }
    }
    System.out.println("No. Birnam and Dunsinane words: " + numWords);
  }  // end of locateWords()


  private int countString(String text, String str)
  // how many times does str appear in text?
  {
    int count = 0;
    int index = 0;
    while ((index = text.indexOf(str, index)) != -1) {
      count++;
      index += str.length();  // skip past str in text
    }
    return count;
  }  // end of countString();

  // -------------------- main() ---------------------

  public static void main(String args[])
  { new MacbethTests();  } 

 } // end of MacbethTests class
